@@ -185,7 +185,7 @@ class analytics_client:
         return metric
 
     @staticmethod
-    def _format_date_range(date_start, date_end):
+    def _format_date_range(date_start, date_end, hour_start, hour_end):
         '''
         Format start and ending date.
 
@@ -194,7 +194,14 @@ class analytics_client:
         Note: The end-date provided is inclusive. For that reason it is converted to the start of the next day. 
 
         Example: If the report needs to end on 1st of March 2020, then the value is convered into 2020-03-02T00:00:00.000
-        
+
+        The hours are being added on top of the existing day. Examples:
+        - If the starting date is 26/11/2020 and starting hour is 13, then the starting time point will be 2020-11-26T13:00:00.000 
+        - (!) If the ending date is 29/11/2020 and ending hour is 17, then the ending time point will be 2020-11-29T17:00:00.000 
+        - (!) If the ending date is 29/11/2020 and ending hour is 0, then the ending time point will be 2020-11-30T00:00:00.000 
+
+        Note: If the ending hour is <> 0, then the full day is captured. Otherwise it captures only the portion of the day.
+
         Parameters
         ----------
         date_start : string
@@ -203,19 +210,26 @@ class analytics_client:
         date_end : string
             Reporting period start date. Format: YYYY-MM-DD i.e. 2018-01-31. The value is converted to 2018-02-01T00:00:00.000
 
+        hour_start: int
+            Reporting period start hour. Integer value from 0 to 24
+
+        hour_end: int
+            Reporting period start hour. Integer value from 0 to 24
+
         Returns
         -------
         string
             The final formated value i.e. 2017-12-31T00:00:00.000/2018-02-01T00:00:00.000        
         '''
         date_start = datetime.strptime(date_start, '%Y-%m-%d')
-        date_start = date_start + timedelta(microseconds=1)
+        date_start = date_start + timedelta(hours = hour_start, microseconds=1)
         date_start = date_start.isoformat('T')
 
         date_end = datetime.strptime(date_end, '%Y-%m-%d')
-        # date_end = date_end + \
-        #     timedelta(hours=23, minutes=59, seconds=59, milliseconds=999)
-        date_end = date_end + timedelta(hours=24, minutes=00, seconds=00, milliseconds=999)
+        
+        if hour_end == 0:
+            hour_end = 24
+        date_end = date_end + timedelta(hours = hour_end, minutes=00, seconds=00, milliseconds=999)
         date_end = date_end.isoformat('T')
         final_date = '{}/{}'.format(date_start[:-7], date_end[:-7])
         return final_date
@@ -539,13 +553,18 @@ class analytics_client:
             segment_filter['segmentId'] = segment_id
             self.report_object['globalFilters'].append(segment_filter)
 
-    def set_date_range(self, date_start, date_end):
+    def set_date_range(self, date_start, date_end, hour_start = 00, hour_end = 24):
         '''
-        Set the start and end date.
+        Set the start and end date. Optional start/end hour.
 
         The starting date and the ending date for the reporting period is saved into the JSON report object.
         The values are first formated in an API-compatible format using _format_date_range function.
         The final value is saved in the JSON report object.
+
+        Optionally the start hour of the start date and the end hour of the end date can be configured.
+        - If the hour_start parameter is set greater than 0, then the date range will start from that time slot onwards.
+        - If the hour_end parameter is not set, then only then the full day will be downloaded.
+        - If the hour_end parameter is set greater than 0, then only the portion of the last day will be downloaded.
         
         Parameters
         ----------
@@ -553,10 +572,16 @@ class analytics_client:
             Reporting period start date. Format: YYYY-MM-DD i.e. 2017-12-31
 
         date_end : string
-            Reporting period start date. Format: YYYY-MM-DD i.e. 2018-01-31.   
+            Reporting period start date. Format: YYYY-MM-DD i.e. 2018-01-31.  
+
+        hour_start: int - optional
+            Reporting period start hour. Integer value from 0 to 24
+
+        hour_end: int - optional
+            Reporting period start hour. Integer value from 0 to 24 
         '''
 
-        formated_date_range = self._format_date_range(date_start=date_start, date_end=date_end)
+        formated_date_range = self._format_date_range(date_start=date_start, date_end=date_end, hour_start = hour_start, hour_end= hour_end)
         date_range_globabl_filter =  {
             "type": "dateRange",
             "dateRange": formated_date_range
